#
# spec file for package helm-docs
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define __arch_install_post export NO_BRP_STRIP_DEBUG=true

Name:           helm-docs
Version:        1.14.2
Release:        1.4
Summary:        A tool for automatically generating markdown documentation for helm charts
License:        GPL-3.0-only
URL:            https://github.com/norwoodj/helm-docs
Source:         helm-docs-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  go >= 1.22

%description
The helm-docs tool auto-generates documentation from helm charts into markdown files. The resulting files contain metadata about their respective chart and a table with each of the chart's values, their defaults, and an optional description parsed from comments.

The markdown generation is entirely gotemplate driven. The tool parses metadata from charts and generates a number of sub-templates that can be referenced in a template file (by default README.md.gotmpl). If no template file is provided, the tool has a default internal template that will generate a reasonably formatted README.

%prep
%setup -q
%setup -q -T -D -a 1

%build
go build \
   -mod=vendor \
   -buildmode=pie \
   -o bin/helm-docs ./cmd/helm-docs

%install
# Install the binary.
install -D -m 0755 bin/%{name} "%{buildroot}/%{_bindir}/%{name}"

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}

%changelog
* Thu Jul 11 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.14.2:
  * Release v1.14.2
  * fix: Adds check for tag format to release script, also makes
    release script error on improper tags
  * chore(deps): bump helm.sh/helm/v3 from 3.15.1 to 3.15.2
* Thu Jul 11 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.14.1:
  * Release 1.14.1
  * Update go.mod via 'go mod tidy'
  * chore: generates documentation using new v1.14.0
* Thu Jul 11 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.14.0:
  * Release 1.14.0
  * fix: Fixes goreleaser action by using new flag
  * chore(deps): bump github.com/stretchr/testify from 1.8.3 to
    1.9.0
  * chore(deps): bump github.com/spf13/cobra from 1.7.0 to 1.8.1
  * chore(deps): bump goreleaser/goreleaser-action from 4 to 6
  * chore(deps): bump alpine from 3.19 to 3.20
  * chore(deps): bump docker/setup-buildx-action from 2 to 3
  * chore(deps): bump docker/setup-qemu-action from 2 to 3
  * chore(deps): bump crazy-max/ghaction-import-gpg from 5 to 6
  * Add dependabot
  * Use helm v3
  * revert go.mod
  * add toYaml example
  * add example
  * chore: set go version to 1.22.0
  * chore: renders example chart documentation using v1.13.1
  * add a flag to remove the version footer
  * feat: add toYaml and fromYaml to functions map
* Sat Mar 16 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.13.1:
  * Release v1.13.1
  * chore: updates golang.org/x/crypto to fix vulnerability
  * Update documentation for default template
  * chore: updates chart docs with v1.13.0
* Sat Feb 24 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.13.0:
  * Release v1.13.0
  * chore: adds git-cliff configuration, generates historical
    changelog and adds a release script
  * fix: Solves #217 where helm-docs would segfault due in charts
    with certain comment format
  * feat: update to use go1.22
  * license: update to use spdx id
  * Update Alpine to v3.19
  * fix: Correct the name of the GitHub repository in the README
    fixes issue #208
  * chore: updates generated chart documentation for version
    v1.12.0
* Thu Dec 21 2023 opensuse_buildservice@ojkastl.de
- Update to version 1.12.0:
  * conform to MD022
  * Change example section chart to new templates
  * Add some comments about parsing of key comments
  * Sectioned values are default if provied
  * Factor out sorting value rows and add dedicated default section
  * Update README.md with pre-commit usage examples
  * Update .pre-commit-hooks.yaml
  * Put the creation and sorting of sectioned Value Rows in its own
  * functions
  * Add Tests for section feature
  * Give an example of how to use sections
  * Add possibility to generate subsectioned Values Tables
  * Pin container version to tagged release v1.11.0
  * Add containerized pre-commit hook
  * Copy NotationType in Nil Values
  * fix(README): change the way helm-docs is installed
  * Fix filename
  * Adds AsMap to iterate over .Files.Glob
* Tue Oct 10 2023 kastl@b1-systems.de
- Update to version 1.11.3:
  * hotfix: changing back artifacts name
  * fix: correct contributing link referent in pr template
  * fix: changed to always get the latest version on the helm docs
    pre commit
  * Bump all available dependencies to latest.
* Wed Sep 20 2023 kastl@b1-systems.de
- Update to version 1.11.2:
  * Revert "fix: String additional empty line from generated
    README.md"
  * chore: update github actions to be able to reproduce using act
  * chore: adding todo to refactor main test
  * fix: removing goreleaser project env var to be able to test
    locally
  * fix: remove var env dependency by moving tests
  * chore: change readme to trigger ci
* Wed Sep 20 2023 kastl@b1-systems.de
- Update to version 1.11.1:
  * chore: change readme to trigger ci
  * Update pkg/helm/chart_info.go
  * fix: change error to err to not conflict with builtin interface
  * fix: update goreleaser and way to get env
  * fix: update actions
  * Fixed GoReleaser
  * Fixing build
  * Fixed deprecation
  * Fixing GoReleaser deprecated action
  * Introducing options from the CLI and unit test to confirm
    strict linting of documentation comments
  * fix: String additional empty line from generated README.md
  * chore: updates example chart READMEs for v1.11.0
* Wed Jun 29 2022 kastl@b1-systems.de
- Update to version 1.11.0:
  * fix: fixes file operations to work when not running from the chart root and fixes several tests
  * adding ignore-non-descriptions flag
  * fix broken file sorting
  * Add an option to list charts to generate
  * Added file lazy loading
  * Improve code according to mjpitz suggestions
  * Rename @section to @raw
  * Add option for ignoring values
  * chore: generate READMEs for example charts with new version
  * Added Helm .Files
* Sat May 14 2022 kastl@b1-systems.de
- Update to version 1.10.0:
  * fix: types on nil values
  * Add support for custom notation type
  * Generated example charts with new version
* Tue Apr 26 2022 kastl@b1-systems.de
- Update to version 1.9.1:
  * Revert "Add angle brackets around urls in requirementsTable"
  * Generated example charts with new version
* Tue Apr 26 2022 kastl@b1-systems.de
- Update to version 1.9.0:
  * Updates alpine docker image to fix issue #124
  * Add angle brackets around urls in requirementsTable
  * Fix issue where an empty global object in a child chart would be listed in the root docs
  * Warn about remote dependencies without erroring; Parse local file:// repositories
  * Fix documented globals prefixed with the sub-chart alias
  * Tolerate dependency charts without values.yaml
  * New flag --document-dependency-values
  * Runs newest helm-docs to update docs for example charts
* Mon Apr  4 2022 kastl@b1-systems.de
- Update to version 1.8.1:
  * Don't print angle brackets for URL/email if not present
* Mon Apr  4 2022 kastl@b1-systems.de
- Update to version 1.8.0:
  * Updgrades sprig to v3
  * Updgrades golang/x/sys to fix #131
  * Add option for a values file named other than `values.yaml`.
  * feat: make the badge style from shields.io configurable
  * Avoid raw URLs in maintainer tables
* Wed Mar  2 2022 Johannes Kastl <kastl@b1-systems.de>
- new package helm-docs: A tool for automatically generating markdown documentation for helm charts
- v1.6.0 and v1.7.0 tags are on the same commit
